alfred3-interact: Interactive web-experiments — alfred3_interact

Skip to main content
`Ctrl`+`K`

# alfred3-interact: Interactive web-experiments

Welcome to the documentation of alfred3-interact! Alfred3-interact is a plugin for alfred3 that offers the creation of interactive web experiments, predominantly in the social sciences. As prerequisites, you need to have Python 3.7 or newer and alfred3 v2.2 or newer installed.

## Installation

Alfred3-interact can be installed via pip:

    $ pip3 install alfred3_interact

## Usage

The composition of groups of multiple participants for data exchange relies on the `MatchMaker` class and its methods `match_random()`, `match_chain()`, and `match_to()`. All of these methods return `Group` objects, which allow you to reference individual participants and their corresponding `GroupMember` objects based on their role in the group.

Within an experiment, you can define waiting points for synchronizing multiple participants’ progress through the `WaitingPage`. We also provide a `Chat` element, which can be comfortably used as a group chat through the shortcut `Group.chat()`. The chat can also be used independently of groups.

Equipped with this narrative information, you can dive into the API documentation and examples to see in more detail how to use alfred3_interact in your alfred3 experiments.

If you have more questions or are stuck somewhere, please do not hesitate to ask your question in alfred3’s GitHub discussions: ctreffe/alfred#q-a

How To

- How To Create an Interactive Experiment
  - Step 1: Preparations
  - Step 2: Make a Match
  - Step 3: Work with the Group
  - Step 4: Use a WaitingPage for Syncing
- How to create groups of different conditions
- How To Use the Admin Tools
  - How to access the admin mode

## API Reference Overview

`MatchMaker` | Creates groups of multiple experiment sessions.
`SequentialSpec` | Interface for defining a sequential group.
`ParallelSpec` | Interface for defining a parallel group.
`IndividualSpec` | Interface for defining an 'individual group spec'.
`Group` | The group object holds members and keeps track of their roles.
`GroupMember` | The group member object grants access to a member's experiment data.
`WaitingPage` | A page that provides a waiting screen for synchronization in interactive experiments.
`MatchMakerActivation` | Admin page for toggling MatchMaker activation.
`MatchMakerMonitoring` | Admin page for monitoring a MatchMaker's work.
`Chat` | Provides a chat window.
`ParallelGroupQuota` | Manages quota for parallel groups.
`SequentialGroupQuota` | Manages quota for sequential groups.
`MetaQuota` | Gives access to aggregated information about open, pending, and finished slots of multiple individual quotas.

# Indices and tables

- Index

- Module Index

- Search Page